@@ -1,6 +1,6 @@
 indicators_example_request = """{
    "queryTerm":"/Users/mknopf/code/test.sh",
-   "enclaveIds":[
+   "enclaveGuids":[
       "3a93fab3-f87a-407a-9376-8eb3fae99b4e"
    ],
    "priorityScores":[
@@ -21,7 +21,7 @@ indicators_example_request = """{
    "cursor":"eyJwYWdlTnVtYmVyIjoxLCJwYWdlU2l6ZSI6Miwib2Zmc2V0Ijo0fQ=="
 }"""
 
-submission_example_request = """
+indicators_submission_example_request = """
 {
   "title": "Report, complex test",
   "content": {
@@ -94,6 +94,19 @@ submission_example_request = """
 }
 """
 
+non_structured_submission_example_request = """
+{
+  "title": "Report, complex test",
+  "content": "MALICIOUS IP: 8.8.8.8",
+  "enclaveGuid": "c0f07a9f-76e4-48df-a0d4-c63ed2edccf0",
+  "externalId": "external-1234",
+  "externalUrl": "externalUrlValue",
+  "timestamp": 1607102497000,
+  "tags": ["random_tag"]
+}
+"""
+
+
 safelist_summaries = """
 [
   {
@@ -153,3 +166,74 @@ entities_extraction = """
   }
 ]
 """
+
+enclaves = """
+[
+  {
+      "name": "test_name_1",
+      "templateName": "Private Enclave",
+      "workflowSupported": false,
+      "read": true,
+      "create": true,
+      "update": true,
+      "id": "test-id-1",
+      "type": "INTERNAL"
+  },
+  {
+      "name": "test_name_2",
+      "templateName": "Private Enclave",
+      "workflowSupported": false,
+      "read": true,
+      "create": true,
+      "update": true,
+      "id": "test-id-2",
+      "type": "INTERNAL"
+  }
+]
+"""
+
+serialized_workflow_config = """
+{
+  "type": "INDICATOR_PRIORITIZATION",
+  "priorityScores": ["MEDIUM", "HIGH"],
+  "observableTypes": ["URL", "IP4", "IP6", "SHA256"],
+  "workflowSource": {
+    "enclaveSourceConfig": [
+      {
+        "enclaveGuid": "test-enclave-id",
+        "weight": 3
+      },
+      {
+        "enclaveGuid": "test-enclave-id2",
+        "weight": 3
+      },
+      {
+        "enclaveGuid": "test-enclave-id3",
+        "weight": 1
+      },
+      {
+        "enclaveGuid": "test-enclave-id4",
+        "weight": 5
+      }
+    ]
+  },
+  "workflowDestination": {
+    "enclaveDestinationConfigs": [
+      {
+        "enclaveGuid": "test-enclave-id",
+        "destinationType": "ENCLAVE"
+      }
+    ]
+  }
+}
+"""
+
+observables_search_example_request = """{
+    "queryTerm": "query",
+    "from":1596607968000,
+    "to":1598308171000,
+    "sortColumn": "FIRST_SEEN",
+    "sortOrder": "ASC",
+    "enclaveGuids": ["4bdc3f5b-3ed5-4d99-b20c-2d801866ef0b"],
+    "types": ["MD5"]
+}"""
