@@ -1,14 +1,17 @@
-from collections import namedtuple
-import dateparser
-from datetime import datetime
 import pytz
-import functools
 import inspect
+import functools
+import dateparser
 
 from enum import Enum
+from datetime import datetime
+from collections import namedtuple
+
 
 
 def get_timestamp(date):
+    if isinstance(date, int):
+        return date
     dt_obj = dateparser.parse(
         date, settings={"TIMEZONE": "UTC", "RETURN_AS_TIMEZONE_AWARE": True}
     )
