@@ -26,20 +26,34 @@ class Query:
     def set_params(self, params):
         self.params = params
 
-    def _update_params_from_response(self, response):
-        if response["responseMetadata"]["nextCursor"] != "":
+    def _update_cursor(self, response):
+        if response["responseMetadata"].get("nextCursor", "") != "":
             cursor = Param("cursor", response["responseMetadata"]["nextCursor"])
             self.params.add(cursor)
         else:
             self.stop = True
 
+    def _update_page(self, response):
+        if response["hasNext"]:
+            currentPage = int(response.get("pageNumber", 0))
+            pageNumber = Param("pageNumber", currentPage + 1)
+            self.params.add(pageNumber)
+        else:
+            self.stop = True
+
+    def _update_params_from_response(self, response):
+        if "responseMetadata" in response.keys():
+            self._update_cursor(response)
+        elif "hasNext" in response.keys():
+            self._update_page(response)
+
     def next(self):
         if not self.stop:
-            result = self.api.fetch(self)
+            result = self.api.fetch(self, use_empty_payload=True)
             self._update_params_from_response(result.json())
             return result
         else:
             raise StopIteration
 
-    def fetch_one(self):
-        return self.api.fetch(self)
+    def execute(self, use_empty_payload=False):
+        return self.api.fetch(self, use_empty_payload)
