@@ -15,6 +15,11 @@ class SortColumns(TSEnum):
     UPDATED = "UPDATED"
 
 
+class SortOrder(TSEnum):
+    ASC = "ASC"
+    DESC = "DESC"
+
+
 class ObservableTypes(TSEnum):
 
     BITCOIN_ADDRESS = "BITCOIN_ADDRESS"
@@ -30,6 +35,7 @@ class ObservableTypes(TSEnum):
     SOFTWARE = "SOFTWARE"
     URL = "URL"
     X_ID = "X_ID"
+    DOMAIN = 'DOMAIN'
 
 
 class AttributeTypes(TSEnum):
@@ -46,3 +52,27 @@ class TruStarUrls(TSEnum):
     API = "https://api.trustar.co/api/2.0"
     AUTH_TOKEN = "https://api.trustar.co/oauth/token"
     STATION = "https://station.trustar.co"
+
+
+class MaxValues(TSEnum):
+
+    TAGS = 20
+    RELATED_OBSERVABLES = 50
+    ATTRIBUTES = 50
+    INDICATORS = 2000
+
+
+class WorkflowDestinations(TSEnum):
+
+    QRADAR = "QRADAR"
+    ENCLAVE = "ENCLAVE"
+    UNKNOWN = "UNKNOWN"
+
+class ID_Types(TSEnum):
+    INTERNAL = "INTERNAL"
+    EXTERNAL = "EXTERNAL"
+    UNRECOGNIZED = "UNRECOGNIZED"
+
+class ObservableSortColumns(TSEnum):
+    FIRST_SEEN = "FIRST_SEEN"
+    LAST_SEEN = "LAST_SEEN"
